@@ -7,7 +7,7 @@
 <?php echo _("Location:") ?> <?php echo $this->event->getLocation($this->user) ?>
 
 
-<?php echo _("Date:") ?> <?php echo $this->event->start->strftime($this->dateFormat) ?>
+<?php echo _("Date:") ?> <?php echo $this->start->strftime($this->dateFormat) ?>
 
 <?php echo _("Time:") ?> <?php echo $this->event->start->format($this->timeFormat) ?>
 
